part of 'select_electricity_location_save_bloc.dart';

abstract class SelectElectricityLocationSaveState extends Equatable {
  const SelectElectricityLocationSaveState();

  @override
  List<Object> get props => [];
}

class SelectElectricityLocationSaveInitial extends SelectElectricityLocationSaveState {
  @override
  List<Object> get props => [];
}

class SelectElectricityLocationSaveLoading extends SelectElectricityLocationSaveState {}

class SelectElectricityLocationSaveLoaded extends SelectElectricityLocationSaveState {
  final bool isSuccess;
  final String errorMessage;

  SelectElectricityLocationSaveLoaded({this.isSuccess, this.errorMessage});
  @override
  List<Object> get props => [isSuccess];
}

class SelectElectricityLocationSaveNotFound extends SelectElectricityLocationSaveState {}

class SelectElectricityLocationSaveError extends SelectElectricityLocationSaveState {
  final String message;
  const SelectElectricityLocationSaveError({this.message});
  @override
  List<Object> get props => [message];
}

class SelectElectricityLocationSaveErrorUnauthorized extends SelectElectricityLocationSaveState {}
